import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { DeleteEarthObservationJobInput, DeleteEarthObservationJobOutput } from "../models/models_0";
import { SageMakerGeospatialClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../SageMakerGeospatialClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteEarthObservationJobCommand}.
 */
export interface DeleteEarthObservationJobCommandInput extends DeleteEarthObservationJobInput {
}
/**
 * @public
 *
 * The output of {@link DeleteEarthObservationJobCommand}.
 */
export interface DeleteEarthObservationJobCommandOutput extends DeleteEarthObservationJobOutput, __MetadataBearer {
}
declare const DeleteEarthObservationJobCommand_base: {
    new (input: DeleteEarthObservationJobCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteEarthObservationJobCommandInput, DeleteEarthObservationJobCommandOutput, SageMakerGeospatialClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteEarthObservationJobCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteEarthObservationJobCommandInput, DeleteEarthObservationJobCommandOutput, SageMakerGeospatialClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Use this operation to delete an Earth Observation job.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SageMakerGeospatialClient, DeleteEarthObservationJobCommand } from "@aws-sdk/client-sagemaker-geospatial"; // ES Modules import
 * // const { SageMakerGeospatialClient, DeleteEarthObservationJobCommand } = require("@aws-sdk/client-sagemaker-geospatial"); // CommonJS import
 * const client = new SageMakerGeospatialClient(config);
 * const input = { // DeleteEarthObservationJobInput
 *   Arn: "STRING_VALUE", // required
 * };
 * const command = new DeleteEarthObservationJobCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteEarthObservationJobCommandInput - {@link DeleteEarthObservationJobCommandInput}
 * @returns {@link DeleteEarthObservationJobCommandOutput}
 * @see {@link DeleteEarthObservationJobCommandInput} for command's `input` shape.
 * @see {@link DeleteEarthObservationJobCommandOutput} for command's `response` shape.
 * @see {@link SageMakerGeospatialClientResolvedConfig | config} for SageMakerGeospatialClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>Updating or deleting a resource can cause an inconsistent state.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The request references a resource which does not exist.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The request was denied due to request throttling.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The input fails to satisfy the constraints specified by an Amazon Web Services service.</p>
 *
 * @throws {@link SageMakerGeospatialServiceException}
 * <p>Base exception class for all service exceptions from SageMakerGeospatial service.</p>
 *
 * @public
 */
export declare class DeleteEarthObservationJobCommand extends DeleteEarthObservationJobCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteEarthObservationJobInput;
            output: {};
        };
        sdk: {
            input: DeleteEarthObservationJobCommandInput;
            output: DeleteEarthObservationJobCommandOutput;
        };
    };
}
